@@ -655,9 +655,17 @@ send_files_cb (MonorailSend *monorail_send,
   dialog_context->selected_files = NULL;
   while (*filenames != NULL)
     {
+      GFile *f;
+
+      /* Applications using sharing-dialog use both format and we should
+       * accept both. */
+      if (g_str_has_prefix (*filenames, "file:"))
+        f = g_file_new_for_uri (*filenames);
+      else
+        f = g_file_new_for_path (*filenames);
+
       dialog_context->selected_files =
-        g_slist_prepend (dialog_context->selected_files,
-            g_file_new_for_uri (*filenames));
+        g_slist_prepend (dialog_context->selected_files, f);
       filenames++;
     }
 
