@@ -658,12 +658,16 @@ transfer_new_handler (MonorailHandler *handler,
 void
 transfer_show_window (MonorailData *monorail_data)
 {
-  TransfersData *data = (TransfersData *) monorail_data->transfers_data;
+  TransfersData *data;
 
   if (monorail_data->transfers_data == NULL)
-    create_transfer_window (monorail_data);
+    {
+      create_transfer_window (monorail_data);
+      data = (TransfersData *) monorail_data->transfers_data;
+    }
   else 
     {
+      data = (TransfersData *) monorail_data->transfers_data;
       if (!data->dialog_visible)
         monorail_transfers_inc (monorail_data, FALSE);
     }
